@@ -583,6 +583,7 @@ class SphinxRenderer:
         for k, v in options.items():
             directive.options[k] = v
 
+        assert self.app.env is not None
         config = self.app.env.config
 
         if config.breathe_debug_trace_directives:
@@ -635,6 +636,8 @@ class SphinxRenderer:
             content_callback = content
         declaration = declaration.replace('\n', ' ')
         nodes_ = self.run_directive(obj_type, declaration, content_callback, options)
+
+        assert self.app.env is not None
         if self.app.env.config.breathe_debug_trace_doxygen_ids:
             target = self.create_doxygen_target(node)
             if len(target) == 0:
@@ -696,6 +699,7 @@ class SphinxRenderer:
         if self.nesting_level > 0:
             return []
 
+        assert self.app.env is not None
         config = self.app.env.config
         if config.breathe_debug_trace_qualification:
             def debug_print_node(n):
@@ -866,6 +870,44 @@ class SphinxRenderer:
             for fl in fieldLists:
                 fieldList.extend(fl)
             fieldLists = [fieldList]
+
+        # collapse retvals into a single return field
+        if len(fieldLists) != 0:
+            others: nodes.field = []
+            retvals: nodes.field = []
+            for f in fieldLists[0]:
+                fn, fb = f
+                assert len(fn) == 1
+                if fn.astext().startswith("returns "):
+                    retvals.append(f)
+                else:
+                    others.append(f)
+            if len(retvals) != 0:
+                items: List[nodes.paragraph] = []
+                for fn, fb in retvals:
+                    # we created the retvals before, so we made this prefix
+                    assert fn.astext().startswith("returns ")
+                    val = nodes.strong('', fn.astext()[8:])
+                    # assumption from visit_docparamlist: fb is a single paragraph or nothing
+                    assert len(fb) <= 1, fb
+                    bodyNodes = [val, nodes.Text(' -- ')]
+                    if len(fb) == 1:
+                        assert isinstance(fb[0], nodes.paragraph)
+                        bodyNodes.extend(fb[0])
+                    items.append(nodes.paragraph('', '', *bodyNodes))
+                # only make a bullet list if there are multiple retvals
+                if len(items) == 1:
+                    body = items[0]
+                else:
+                    body = nodes.bullet_list()
+                    for i in items:
+                        body.append(nodes.list_item('', i))
+                fRetvals = nodes.field('',
+                                       nodes.field_name('', 'returns'),
+                                       nodes.field_body('', body))
+                fl = nodes.field_list('', *others, fRetvals)
+                fieldLists = [fl]
+
         if self.app.config.breathe_order_parameters_first:  # type: ignore
             return brief + detailed + fieldLists + admonitions
         else:
@@ -1684,6 +1726,8 @@ class SphinxRenderer:
         return nodelist
 
     def visit_docxrefsect(self, node) -> List[Node]:
+        assert self.app.env is not None
+
         signode = addnodes.desc_signature()
         title = node.xreftitle[0] + ':'
         titlenode = nodes.emphasis(text=title)
@@ -1813,11 +1857,13 @@ class SphinxRenderer:
                     elements.append('virtual')
                 if node.explicit == 'yes':
                     elements.append('explicit')
-                if 'constexpr' in dir(node):
-                    assert node.constexpr == 'yes'
-                    elements.append('constexpr')
-                elements.append(''.join(n.astext()
-                                        for n in self.render(node.get_type())))  # type: ignore
+                # TODO: handle constexpr when parser has been updated
+                #       but Doxygen seems to leave it in the type anyway
+                typ = ''.join(n.astext() for n in self.render(node.get_type()))
+                # Doxygen sometimes leaves 'static' in the type,
+                # e.g., for "constexpr static auto f()"
+                typ = typ.replace('static ', '')
+                elements.append(typ)
                 elements.append(name)
                 elements.append(node.get_argsstring())
                 declaration = ' '.join(elements)
@@ -1859,6 +1905,8 @@ class SphinxRenderer:
             self.context.directive_args[1] = [signature]
 
             nodes = self.run_domain_directive(node.kind, self.context.directive_args[1])
+
+            assert self.app.env is not None
             if self.app.env.config.breathe_debug_trace_doxygen_ids:
                 target = self.create_doxygen_target(node)
                 if len(target) == 0:
@@ -2049,7 +2097,7 @@ class SphinxRenderer:
                         location=self.state.state_machine.get_source_and_line(),
                         config=self.app.config)
                     try:
-                        # we really should use _parse_template_paramter()
+                        # we really should use _parse_template_parameter()
                         # but setting a name there is non-trivial, so we use type
                         ast = parser._parse_type(named='single', outer='templateParam')
                         assert ast.name is None
